==> ckan-2.5.3.tar.gz: ckan-2.5.3/ckan/public/base/i18n/it.js <==
{
  "": {
    "domain": "ckan",
    "lang": "it",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "An Error Occurred": [
    null,
    "Si è verificato un errore"
  ],
  "An error occurred: %(text)s %(error)s": [
    null,
    "Si è verificato un errore: %(text)s %(error)s"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Si è certi di voler confermare questa azione?"
  ],
  "Cancel": [
    null,
    "Annulla"
  ],
  "Confirm": [
    null,
    "Conferma"
  ],
  "Edit": [
    null,
    "Modifica"
  ],
  "Failed to load data API information": [
    null,
    "Lettura dei dati attraverso le API fallita"
  ],
  "Follow": [
    null,
    "Segui"
  ],
  "Hide": [
    null,
    "Nascondi"
  ],
  "Image": [
    null,
    "Immagine"
  ],
  "Input is too short, must be at least one character": [
    null,
    "Troppo breve! Il testo deve contenere almeno un carattere"
  ],
  "Link": [
    null,
    "Link"
  ],
  "Link to a URL on the internet (you can also link to an API)": [
    null,
    "Link a un indirizzo internet (puoi anche inserire l'URL di un API)"
  ],
  "Loading...": [
    null,
    "Caricamento in corso ..."
  ],
  "No matches found": [
    null,
    "Elementi non trovati"
  ],
  "Please Confirm Action": [
    null,
    "Confermare azione"
  ],
  "Remove": [
    null,
    "Rimuovi"
  ],
  "Reorder resource view": [
    null,
    "Riordina vista di risorsa"
  ],
  "Reorder resources": [
    null,
    "Riordina risorse"
  ],
  "Resource uploaded": [
    null,
    "Risorsa caricata"
  ],
  "Save order": [
    null,
    "Salva ordine"
  ],
  "Saving...": [
    null,
    "Salvataggio in corso..."
  ],
  "Show more": [
    null,
    "Mostra più"
  ],
  "Start typing…": [
    null,
    "Inizia a scrivere..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Ci sono modifiche non salvate per questa form"
  ],
  "There is no API data to load for this resource": [
    null,
    "Non ci sono dati da caricare via API per questa risorsa "
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Impossibile autenticare il caricamento"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Impossibile accedere ai dati per il file caricato"
  ],
  "Unable to upload file": [
    null,
    "Impossibile caricare il file"
  ],
  "Unfollow": [
    null,
    "Non seguire più"
  ],
  "Upload": [
    null,
    "Carica"
  ],
  "Upload a file": [
    null,
    "Carica un file"
  ],
  "Upload a file on your computer": [
    null,
    "Carica un file dal computer"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Stai caricando un file. Si è sicuri di voler abbandonare questa pagina e interrompere il caricamento?"
  ],
  "error loading view": [
    null,
    "errore nel caricamento della vista"
  ],
  "show less": [
    null,
    "visualizzane meno"
  ],
  "show more": [
    null,
    "visualizzane di più"
  ]
}

==> ckan-2.6.0.tar.gz: ckan-2.6.0/ckan/public/base/i18n/it.js <==
{
  "": {
    "domain": "ckan",
    "lang": "it",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "An Error Occurred": [
    null,
    "Si è verificato un errore"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Sei certo di voler confermare questa azione?"
  ],
  "Cancel": [
    null,
    "Annulla"
  ],
  "Confirm": [
    null,
    "Conferma"
  ],
  "Edit": [
    null,
    "Modifica"
  ],
  "Failed to load data API information": [
    null,
    "Lettura dei dati attraverso le API fallita"
  ],
  "File": [
    null,
    "File"
  ],
  "Follow": [
    null,
    "Segui"
  ],
  "Hide": [
    null,
    "Nascondi"
  ],
  "Image": [
    null,
    "Immagine"
  ],
  "Input is too short, must be at least one character": [
    null,
    "Troppo breve! Il testo deve contenere almeno un carattere"
  ],
  "Link": [
    null,
    "Link"
  ],
  "Link to a URL on the internet (you can also link to an API)": [
    null,
    "Link a un indirizzo internet (puoi anche inserire l'URL di un API)"
  ],
  "Loading...": [
    null,
    "Caricando..."
  ],
  "No matches found": [
    null,
    "Elementi non trovati"
  ],
  "Please Confirm Action": [
    null,
    "Confermare azione"
  ],
  "Remove": [
    null,
    "Rimuovi"
  ],
  "Reorder resource view": [
    null,
    "Riordina vista di risorsa"
  ],
  "Reorder resources": [
    null,
    "Riordina risorse"
  ],
  "Resource uploaded": [
    null,
    "Risorsa caricata"
  ],
  "Save order": [
    null,
    "Salva ordine"
  ],
  "Saving...": [
    null,
    "Salvataggio in corso..."
  ],
  "Show more": [
    null,
    "Mostra più"
  ],
  "Start typing…": [
    null,
    "Inizia a scrivere..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Ci sono modifiche non salvate per questa form"
  ],
  "There is no API data to load for this resource": [
    null,
    "Non ci sono dati da caricare via API per questa risorsa "
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Impossibile autenticare il caricamento"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Impossibile accedere ai dati per il file caricato"
  ],
  "Unable to upload file": [
    null,
    "Impossibile caricare il file"
  ],
  "Unfollow": [
    null,
    "Non seguire più"
  ],
  "Upload": [
    null,
    "Carica"
  ],
  "Upload a file": [
    null,
    "Carica un file"
  ],
  "Upload a file on your computer": [
    null,
    "Carica un file dal computer"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Stai caricando un file. Sei sicuro che vuoi abbandonare questa pagina e interrompere il caricamento?"
  ]
}
